Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(122)

Unified Diff: src/compiler/interpreter-assembler.h

Issue 1254293006: [interpreter] Change interpreter to use an BytecodeArray pointer and and offset. (Closed) Base URL: ssh://rmcilroy.lon.corp.google.com///usr/local/google/code/v8_full/v8@master
Patch Set: Fix MIPS merge error Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/ia32/linkage-ia32.cc ('k') | src/compiler/interpreter-assembler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/interpreter-assembler.h
diff --git a/src/compiler/interpreter-assembler.h b/src/compiler/interpreter-assembler.h
index edbe86d07bfa290ce3bb7dada672587ffa1d1390..b03e57a5f9681fa42ed9326bfedeac9294e9838a 100644
--- a/src/compiler/interpreter-assembler.h
+++ b/src/compiler/interpreter-assembler.h
@@ -68,9 +68,11 @@ class InterpreterAssembler {
Graph* graph();
private:
- // Returns the pointer to the current bytecode.
- Node* BytecodePointer();
- // Returns the pointer to first entry in the interpreter dispatch table.
+ // Returns a tagged pointer to the current function's BytecodeArray object.
+ Node* BytecodeArrayPointer();
+ // Returns the offset from the BytecodeArrayPointer of the current bytecode.
+ Node* BytecodeOffset();
+ // Returns a pointer to first entry in the interpreter dispatch table.
Node* DispatchTablePointer();
// Returns the frame pointer for the current function.
Node* FramePointer();
@@ -79,8 +81,8 @@ class InterpreterAssembler {
Node* RegisterFrameOffset(int index);
Node* RegisterFrameOffset(Node* index);
// Returns BytecodePointer() advanced by delta bytecodes. Note: this does not
// update BytecodePointer() itself.
Node* Advance(int delta);
// Sets the end node of the graph.
« no previous file with comments | « src/compiler/ia32/linkage-ia32.cc ('k') | src/compiler/interpreter-assembler.cc » ('j') | no next file with comments »
@@ -79,8 +81,8 @@ class InterpreterAssembler {
Node* RegisterFrameOffset(int index);
Node* RegisterFrameOffset(Node* index);
- // Returns BytecodePointer() advanced by delta bytecodes. Note: this does not
- // update BytecodePointer() itself.
+ // Returns BytecodeOffset() advanced by delta bytecodes. Note: this does not
+ // update BytecodeOffset() itself.
Node* Advance(int delta);
// Sets the end node of the graph.

Powered by Google App Engine
This is Rietveld 408576698